pub(crate) struct UiAgents {
pub(crate) state: Vec<AgentState>,
pub(crate) active_agent: usize,
}Expand description
Data for the agents currently running
Fields
state: Vec<AgentState>State of the main agent and subagents
active_agent: usizeWhich agent is being viewed (0 = main agent)
Implementations
Sourceimpl UiAgents
impl UiAgents
Sourcepub(crate) fn new(
main_client_state: Arc<RwLock<ClientState>>,
main_client_info: ClientInfo,
main_history: Arc<Mutex<ChatHistory>>,
) -> Self
pub(crate) fn new( main_client_state: Arc<RwLock<ClientState>>, main_client_info: ClientInfo, main_history: Arc<Mutex<ChatHistory>>, ) -> Self
Create a new collection of agents, with a single main agent
Sourcepub(crate) fn add_subagent(
&mut self,
subagent_id: SubagentId,
prompt: String,
client_info: ClientInfo,
client_state: Arc<RwLock<ClientState>>,
history: Arc<Mutex<ChatHistory>>,
)
pub(crate) fn add_subagent( &mut self, subagent_id: SubagentId, prompt: String, client_info: ClientInfo, client_state: Arc<RwLock<ClientState>>, history: Arc<Mutex<ChatHistory>>, )
Add a new subagent at the end of our list
Sourcepub(crate) fn remove_subagent(&mut self, subagent_id: SubagentId)
pub(crate) fn remove_subagent(&mut self, subagent_id: SubagentId)
Remove a subagent by its ID
If the subagent is currently active, change the active view to the main agent.
Sourcepub(crate) fn active(&self) -> &AgentState
pub(crate) fn active(&self) -> &AgentState
Return the currently active view’s agent
Sourcepub(crate) fn active_mut(&mut self) -> &mut AgentState
pub(crate) fn active_mut(&mut self) -> &mut AgentState
Return the currently active view’s agent, mutably
Sourcepub(crate) fn is_main(&self) -> bool
pub(crate) fn is_main(&self) -> bool
Return whether the currently active view is the main agent’s
Sourcepub(crate) fn active_agent_id(&self) -> AgentId
pub(crate) fn active_agent_id(&self) -> AgentId
Return the ID of the agent in the currently active view
Sourcepub(crate) fn subagent_index(&self) -> Option<usize>
pub(crate) fn subagent_index(&self) -> Option<usize>
Return the subagent index, if viewing a subagent
Sourcepub(crate) fn subagent_count(&self) -> usize
pub(crate) fn subagent_count(&self) -> usize
Return the number of subagents
Sourcepub(crate) fn subagent_task(&self) -> Option<&str>
pub(crate) fn subagent_task(&self) -> Option<&str>
If the currently active view is a subagent, return its task prompt (if known)
Sourcepub(crate) fn switch_prev(&mut self)
pub(crate) fn switch_prev(&mut self)
Switch to the previous agent (wrapping)
Sourcepub(crate) fn switch_next(&mut self)
pub(crate) fn switch_next(&mut self)
Switch to the next agent (wrapping)